@@ -1,5 +1,4 @@
 {-# LANGUAGE BangPatterns       #-}
-{-# LANGUAGE CPP                #-}
 {-# LANGUAGE DeriveDataTypeable #-}
 {-# LANGUAGE DeriveFoldable     #-}
 {-# LANGUAGE DeriveGeneric      #-}
@@ -40,17 +39,12 @@ module Numeric.RootFinding
     -- $references
     ) where
 
-import Control.Applicative              (Alternative(..), Applicative(..))
+import Control.Applicative              (Alternative(..))
 import Control.Monad                    (MonadPlus(..), ap)
 import Control.DeepSeq                  (NFData(..))
 import Data.Data                        (Data, Typeable)
-import Data.Monoid                      (Monoid(..))
-import Data.Foldable                    (Foldable)
-import Data.Traversable                 (Traversable)
 import Data.Default.Class
-#if __GLASGOW_HASKELL__ > 704
 import GHC.Generics                     (Generic)
-#endif
 import Numeric.MathFunctions.Comparison (within,eqRelErr)
 import Numeric.MathFunctions.Constants  (m_epsilon)
 
@@ -61,39 +55,31 @@ import Numeric.MathFunctions.Constants  (m_epsilon)
 ----------------------------------------------------------------
 
 -- | The result of searching for a root of a mathematical function.
-data Root a = NotBracketed
-            -- ^ The function does not have opposite signs when
-            -- evaluated at the lower and upper bounds of the search.
-            | SearchFailed
-            -- ^ The search failed to converge to within the given
-            -- error tolerance after the given number of iterations.
-            | Root !a
-            -- ^ A root was successfully found.
-              deriving (Eq, Read, Show, Typeable, Data, Foldable, Traversable
-#if __GLASGOW_HASKELL__ > 704
-                       , Generic
-#endif
-                       )
+data Root a
+  = NotBracketed
+    -- ^ The function does not have opposite signs when
+    -- evaluated at the lower and upper bounds of the search.
+  | SearchFailed
+    -- ^ The search failed to converge to within the given
+    -- error tolerance after the given number of iterations.
+  | Root !a
+    -- ^ A root was successfully found.
+  deriving (Eq, Read, Show, Typeable, Data, Foldable, Traversable, Functor, Generic)
 
 instance (NFData a) => NFData (Root a) where
     rnf NotBracketed = ()
     rnf SearchFailed = ()
     rnf (Root a)     = rnf a
 
-instance Functor Root where
-    fmap _ NotBracketed = NotBracketed
-    fmap _ SearchFailed = SearchFailed
-    fmap f (Root a)     = Root (f a)
-
 instance Applicative Root where
-    pure  = return
+    pure  = Root
     (<*>) = ap
 
 instance Monad Root where
     NotBracketed >>= _ = NotBracketed
     SearchFailed >>= _ = SearchFailed
     Root a       >>= f = f a
-    return = Root
+    return = pure
 
 instance MonadPlus Root where
     mzero = empty
@@ -128,11 +114,7 @@ data Tolerance
     --   considered approximately equal if \[ |a - b| < \delta \].
     --   Note that @AbsTol 0@ could be used to require to find
     --   approximation within machine precision.
-  deriving (Eq, Read, Show, Typeable, Data
-#if __GLASGOW_HASKELL__ > 704
-           , Generic
-#endif
-           )
+  deriving (Eq, Read, Show, Typeable, Data, Generic)
 
 -- | Check that two values are approximately equal. In addition to
 --   specification values are considered equal if they're within 1ulp
@@ -179,11 +161,7 @@ data RiddersParam = RiddersParam
     -- ^ Error tolerance for root approximation. Default is relative
     --   error 4·ε, where ε is machine precision.
   }
-  deriving (Eq, Read, Show, Typeable, Data
-#if __GLASGOW_HASKELL__ > 704
-           , Generic
-#endif
-           )
+  deriving (Eq, Read, Show, Typeable, Data, Generic)
 
 instance Default RiddersParam where
   def = RiddersParam
@@ -202,11 +180,7 @@ data RiddersStep
   -- ^ Root found
   | RiddersNoBracket
   -- ^ Root is not bracketed
-  deriving (Eq, Read, Show, Typeable, Data
-#if __GLASGOW_HASKELL__ > 704
-           , Generic
-#endif
-           )
+  deriving (Eq, Read, Show, Typeable, Data, Generic)
 
 instance NFData RiddersStep where
   rnf x = x `seq` ()
@@ -295,11 +269,7 @@ data NewtonParam = NewtonParam
     -- ^ Error tolerance for root approximation. Default is relative
     --   error 4·ε, where ε is machine precision
   }
-  deriving (Eq, Read, Show, Typeable, Data
-#if __GLASGOW_HASKELL__ > 704
-           , Generic
-#endif
-           )
+  deriving (Eq, Read, Show, Typeable, Data, Generic)
 
 instance Default NewtonParam where
   def = NewtonParam
@@ -318,11 +288,8 @@ data NewtonStep
   -- ^ Root is found
   | NewtonNoBracket
   -- ^ Root is not bracketed
-  deriving (Eq, Read, Show, Typeable, Data
-#if __GLASGOW_HASKELL__ > 704
-           , Generic
-#endif
-           )
+  deriving (Eq, Read, Show, Typeable, Data, Generic)
+
 instance NFData NewtonStep where
   rnf x = x `seq` ()
 
