@@ -16,10 +16,8 @@ module Numeric.SpecFunctions.Internal
     , Compat.expm1
     ) where
 
-import Control.Applicative
 import Data.Bits          ((.&.), (.|.), shiftR)
 import Data.Int           (Int64)
-import Data.Word          (Word)
 import Data.Default.Class
 import qualified Data.Vector.Unboxed as U
 import           Data.Vector.Unboxed   ((!))
@@ -151,7 +149,7 @@ logGamma z
   -- > (z + 1) - 1 = z
   -- > (z + 1) - 2 = z - 1
   --
-  -- Simple passing (z + 1) to piecewise approxiations and computing
+  -- Simple passing (z + 1) to piecewise approximations and computing
   -- difference leads to bad loss of precision near 1.
   -- This is reason lgamma1_15 & lgamma15_2 have three parameters
   | z < 0.5   = lgamma1_15 z (z - 1) - log z
@@ -283,7 +281,7 @@ tableLogGamma_2_3Q = U.fromList
 
 -- For small z we can just use Gamma function recurrence and reduce
 -- problem to interval [2,3] and use polynomial approximation
--- there. Surpringly it gives very good precision
+-- there. Surprisingly it gives very good precision
 lgammaSmall :: Double -> Double
 lgammaSmall = go 0
   where
@@ -297,7 +295,7 @@ lgammaSmall = go 0
 --
 -- > Γ(z) = sqrt(2π)(z + g - 0.5)^(z - 0.5)·exp{-(z + g - 0.5)}·A_g(z)
 --
--- Coeffients are taken from boost. Constants are absorbed into
+-- Coefficients are taken from boost. Constants are absorbed into
 -- polynomial's coefficients.
 lanczosApprox :: Double -> Double
 lanczosApprox z
@@ -516,7 +514,7 @@ invIncompleteGamma a p
         -- New approximation to x
         x'   | x < dx    = 0.5 * x -- Do not go below 0
              | otherwise = x - dx
-    -- Calculate inital guess for root
+    -- Calculate initial guess for root
     guess
       --
       | a > 1   =
@@ -619,7 +617,7 @@ incompleteBeta_ beta p q x
   | otherwise        = 1 - incompleteBetaWorker beta q p (1 - x)
 
 
--- Approximation of incomplete beta by quandrature.
+-- Approximation of incomplete beta by quadrature.
 --
 -- Note that x =< p/(p+q)
 incompleteBetaApprox :: Double -> Double -> Double -> Double -> Double
@@ -750,7 +748,7 @@ invIncBetaGuess :: Double -> Double -> Double -> Double -> Double
 -- It's really hodgepodge of different approximations accumulated over years.
 --
 -- Equations are referred to by name of paper and number e.g. [AS64 2]
--- In AS64 papers equations are not numbered so they are refered to by
+-- In AS64 papers equations are not numbered so they are referred to by
 -- number of appearance starting from definition of incomplete beta.
 invIncBetaGuess beta a b p
   -- If both a and b are less than 1 incomplete beta have inflection
