@@ -22,7 +22,7 @@ import Tests.Helpers
 import Tests.SpecFunctions.Tables
 import Numeric.SpecFunctions
 import Numeric.SpecFunctions.Internal   (factorialTable)
-import Numeric.MathFunctions.Comparison (within,relativeError,ulpDistance)
+import Numeric.MathFunctions.Comparison (within,ulpDistance)
 import Numeric.MathFunctions.Constants  (m_epsilon,m_tiny)
 
 erfTol,erfcTol,erfcLargeTol :: Int
@@ -36,6 +36,11 @@ erfcLargeTol = 64
 erfTol       = 2
 erfcTol      = 2
 erfcLargeTol = 2
+-- Windows' one is not very good too
+#elif defined(mingw32_HOST_OS)
+erfTol       = 2
+erfcTol      = 2
+erfcLargeTol = 4
 #else
 erfTol       = 1
 erfcTol      = 2
@@ -60,7 +65,7 @@ isWindows = False
 tests :: TestTree
 tests = testGroup "Special functions"
   [ testGroup "erf"
-    [ -- implementation from numerical recipes loses presision for
+    [ -- implementation from numerical recipes loses precision for
       -- large arguments
       testCase "erfc table" $
         forTable "tests/tables/erfc.dat" $ \[x, exact] ->
@@ -236,6 +241,10 @@ roundtrip_erf_invErf   = (128,128)
 roundtrip_erfc_invErfc = (4,4)
 roundtrip_invErfc_erfc = (4,4)
 roundtrip_erf_invErf   = (2,2)
+#elif defined(mingw32_HOST_OS)
+roundtrip_erfc_invErfc = (4,4)
+roundtrip_invErfc_erfc = (4,4)
+roundtrip_erf_invErf   = (4,4)
 #else
 roundtrip_erfc_invErfc = (2,2)
 roundtrip_invErfc_erfc = (2,2)
